==> org.Pf.plasmo.db_3.1.2.tar.gz: org.Pf.plasmo.db/man/org.Pf.plasmoSYMBOL.Rd <==
\name{org.Pf.plasmoSYMBOL}
\alias{org.Pf.plasmoSYMBOL}
\alias{org.Pf.plasmoSYMBOL2ORF}
\title{Map between ORF Identifiers and Gene Symbols}
\description{
  org.Pf.plasmoSYMBOL is an R object that provides mappings between
  ORF identifiers and gene abbreviations. 
}
\details{
  Each ORF identifier is mapped to the a common abbreviation for 
  the corresponding gene. An \code{NA} is reported if there is no known
  abbreviation for a given gene.
  
  Symbols typically consist of 3 letters that define either a single
  gene (ABC) or multiple genes (ABC1, ABC2, ABC3). Gene symbols can be
  used as key words to query public databases such as ORF.

  Mappings were based on data provided by: Plasmo DB  
  http://plasmodb.org/common/downloads/release-13.0/Pfalciparum3D7/txt/  
  With a date stamp from the source of: 14-Jan-2015
  
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
}
\examples{
        x <- org.Pf.plasmoSYMBOL
        # Get the gene symbol that are mapped to an ORF identifiers
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the SYMBOL for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        # For the reverse map:
        x <- org.Pf.plasmoSYMBOL2ORF
        # Get the ORF identifiers that are mapped to a gene symbol
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ORF ID for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}

\keyword{datasets}

==> org.Pf.plasmo.db_3.3.0.tar.gz: org.Pf.plasmo.db/man/org.Pf.plasmoSYMBOL.Rd <==
\name{org.Pf.plasmoSYMBOL}
\alias{org.Pf.plasmoSYMBOL}
\alias{org.Pf.plasmoSYMBOL2ORF}
\title{Map between ORF Identifiers and Gene Symbols}
\description{
  org.Pf.plasmoSYMBOL is an R object that provides mappings between
  ORF identifiers and gene abbreviations. 
}
\details{
  Each ORF identifier is mapped to the a common abbreviation for 
  the corresponding gene. An \code{NA} is reported if there is no known
  abbreviation for a given gene.
  
  Symbols typically consist of 3 letters that define either a single
  gene (ABC) or multiple genes (ABC1, ABC2, ABC3). Gene symbols can be
  used as key words to query public databases such as ORF.

  Mappings were based on data provided by: Plasmo DB  
  http://plasmodb.org/common/downloads/release-25/Pfalciparum3D7/txt/  
  With a date stamp from the source of: 20-Jul-2015
  
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
}
\examples{
        x <- org.Pf.plasmoSYMBOL
        # Get the gene symbol that are mapped to an ORF identifiers
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the SYMBOL for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        # For the reverse map:
        x <- org.Pf.plasmoSYMBOL2ORF
        # Get the ORF identifiers that are mapped to a gene symbol
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ORF ID for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}

\keyword{datasets}
